@@ -23,19 +23,20 @@ class TestPipeRelay(MoxTestBase, unittest.TestCase):
 
     def test_attempt(self):
         self.mox.StubOutWithMock(subprocess, 'Popen')
-        env = Envelope('sender@example.com', ['rcpt1@example.com', 'rcpt2@example.com', 'rcpt3@example.com', 'rcpt4@example.com'])
+        env = Envelope('sender@example.com', ['rcpt1@example.com', 'rcpt2@example.com', 'rcpt3@example.com', 'rcpt4@example.com', 'rcpt5@example.com'])
         env.parse(b'From: sender@example.com\r\n\r\ntest test\r\n')
         self._mock_popen('rcpt1@example.com', 0, '')
         self._mock_popen('rcpt2@example.com', 1337, 'transient')
         self._mock_popen('rcpt3@example.com', 1337, '5.0.0 permanent')
-        subprocess.Popen(['relaytest', '-f', 'sender@example.com', 'rcpt4@example.com'],
+        self._mock_popen('rcpt4@example.com', 1337, b'5.0.0 permanent')
+        subprocess.Popen(['relaytest', '-f', 'sender@example.com', 'rcpt5@example.com'],
                          stdin=subprocess.PIPE,
                          stdout=subprocess.PIPE,
                          stderr=subprocess.PIPE).AndRaise(Timeout)
         self.mox.ReplayAll()
         m = PipeRelay(['relaytest', '-f', '{sender}', '{recipient}'])
         results = m.attempt(env, 0)
-        self.assertEqual(4, len(results))
+        self.assertEqual(5, len(results))
         self.assertEqual(None, results['rcpt1@example.com'])
         self.assertIsInstance(results['rcpt2@example.com'], TransientRelayError)
         self.assertEqual('transient', str(results['rcpt2@example.com']))
@@ -43,9 +44,12 @@ class TestPipeRelay(MoxTestBase, unittest.TestCase):
         self.assertIsInstance(results['rcpt3@example.com'], PermanentRelayError)
         self.assertEqual('5.0.0 permanent', str(results['rcpt3@example.com']))
         self.assertEqual('550', results['rcpt3@example.com'].reply.code)
-        self.assertIsInstance(results['rcpt4@example.com'], TransientRelayError)
-        self.assertEqual('Delivery timed out', str(results['rcpt4@example.com']))
-        self.assertEqual('450', results['rcpt4@example.com'].reply.code)
+        self.assertIsInstance(results['rcpt4@example.com'], PermanentRelayError)
+        self.assertEqual('5.0.0 permanent', str(results['rcpt4@example.com']))
+        self.assertEqual('550', results['rcpt4@example.com'].reply.code)
+        self.assertIsInstance(results['rcpt5@example.com'], TransientRelayError)
+        self.assertEqual('Delivery timed out', str(results['rcpt5@example.com']))
+        self.assertEqual('450', results['rcpt5@example.com'].reply.code)
 
 
 class TestMaildropRelay(MoxTestBase, unittest.TestCase):
